GeneralSecurityProfile

Trait GeneralSecurityProfile 

pub trait GeneralSecurityProfile {
    // Required methods
    fn identifier_allowed(self) -> bool;
    fn identifier_type(self) -> Option<IdentifierType>;
}
Methods for determining characters not restricted from use for identifiers.

Required Methods

fn identifier_allowed(self) -> bool

Returns whether the character is not restricted from use for identifiers.

fn identifier_type(self) -> Option<IdentifierType>

Returns the identifier type

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl GeneralSecurityProfile for char

Implementors